## 外汇日线行情

接口：fx_daily

描述：获取外汇日线行情

限量：单次最大提取1000行记录，可多次提取，总量不限制

积分：用户需要至少2000积分才可以调取，但有流量控制，5000积分以上频次相对较高，积分越多权限越大，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 |
| trade_date | str | N | 交易日期（GMT，日期是格林尼治时间，比北京时间晚一天） |
| start_date | str | N | 开始日期（GMT） |
| end_date | str | N | 结束日期（GMT） |
| exchange | str | N | 交易商，目前只有FXCM |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 外汇代码 |
| trade_date | str | Y | 交易日期 |
| bid_open | float | Y | 买入开盘价 |
| bid_close | float | Y | 买入收盘价 |
| bid_high | float | Y | 买入最高价 |
| bid_low | float | Y | 买入最低价 |
| ask_open | float | Y | 卖出开盘价 |
| ask_close | float | Y | 卖出收盘价 |
| ask_high | float | Y | 卖出最高价 |
| ask_low | float | Y | 卖出最低价 |
| tick_qty | int | Y | 报价笔数 |
| exchange | str | N | 交易商 |

接口示例

```python
pro = ts.pro_api()


#获取美元人民币交易对的日线行情
df = pro.fx_daily(ts_code='USDCNH.FXCM', start_date='20190101', end_date='20190524')
```

数据示例

```python
ts_code trade_date  bid_open  bid_close  bid_high  bid_low  ask_open  \
0    USDCNH.FXCM   20190524    6.9261     6.9326    6.9342   6.9248    6.9277   
```